pub struct DatabaseConfig {}Expand description
Represents the application-level configuration section that covers everything related to database connectivity, primarily the instance URL and credentials for all database servers that this application works with.
This config comes with a custom Deserialize implementation, to support more
human-oriented textual configuration.