Gate

Struct Gate 

pub struct Gate { /* private fields */ }
A single-release barrier that is opened when the associated Latch is released.

This gate can be cheaply cloned and awaited on by any number of asynchronous tasks at any time.

Implementations

Source

impl Gate

pub async fn opened(&self)

Waits asynchronously until the associated Latch is released. Resolves immediately if the latch has already been released.

pub fn is_open(&self) -> bool

Reports whether the associated Latch has been released.