pub struct MigrationsWorker<DB>{ /* private fields */ }Expand description
An asynchronous worker that applies database migrations in the background
and signals completion to whoever cares to listen via the returned Gate.
Implementations
Sourceimpl<DB> MigrationsWorker<DB>
impl<DB> MigrationsWorker<DB>
Sourcepub async fn start(
name: impl AsRef<str>,
migrator: &'static Migrator,
pool: Pool<DB>,
) -> Gate
pub async fn start( name: impl AsRef<str>, migrator: &'static Migrator, pool: Pool<DB>, ) -> Gate
Starts applying migrations using the given static reference to a
migrator and the given pool of database
connections. The given name is attached to this MigrationsWorker
for logging/alerting purposes.
The returned Gate can be used to await for the migrations to be
successfully applied.