pub struct Connector<DB>where
DB: Database,{ /* private fields */ }Expand description
Runs in the background, holds a copy of sqlx database connection Pool
created from the given [Handle], and closes the pooled connections once
the global AppContext is terminated.
In all fairness, this Connector does no “connecting” whatsoever: it
merely lazily initializes a Pool, holds a copy of it, and returns
another copy to the caller. All database connectivity logic is implemented
by the pool itself. The main purpose of this connector is to clean up during
AppSpindown.
Implementations
Sourceimpl<DB> Connector<DB>where
DB: Database,
impl<DB> Connector<DB>where
DB: Database,
Sourcepub fn start<H>(handle: H) -> Pool<DB>where
H: Handle<Database = DB>,
pub fn start<H>(handle: H) -> Pool<DB>where
H: Handle<Database = DB>,
Creates a new Connector for the given [Handle] and sends it into
background to eventually close the pooled database connections once the
global AppContext is terminated.
The returned Pool may be cloned and re-used as necessary.